library(ggplot2)
library(kableExtra)
library(summarytools)
library(hrbrthemes)
library(psych)
library(tidyverse)
library(viridis)
library(reshape)
library(broom)
library(knitr)
library(qwraps2)

## IMPORT DES FICHIERS  =========================================================================================

if ( Sys.info()[c("nodename")] == "DESKTOP-MRLHPQC" )   {chemin <- "D:/Dropbox/UIMM/"} 
if ( Sys.info()[c("nodename")] == "G6513" )             {chemin <-"C:/Users/silva.j/Dropbox/UIMM/"} 

DB  <-readRDS(paste(chemin,"BorderLine Jerome/7 - Article 1/Soumissions/Dataset Borderline.rds"         ,sep=""))

# On enlve les 22 intermediaires :
# par cohrence avec l'article prcdent.

DB <- DB[which(!is.na(DB$borderline)),]

###########################################################################################################
# on importe les CSP donnes par Marion  :
library(openxlsx)
CSP <- read.xlsx(paste(chemin,"BorderLine Jerome/7 - Article 1/Soumissions/2eme reviewer/CSP marion.xlsx",sep=""),
                 sheet = 1,colNames = TRUE)
X <- merge(DB,CSP, by.x="z1" , by.y="num" , all.x=TRUE )
table(X$CSP,X$CSP_bin)
DB <- X
table(DB$CSP_bin, exclude = NULL)

# 3 classes : 1 , 2 , 3
# 1 high 
# 2 intermediaires
# 3 unemployed & retired


table(DB$CSP, DB$CSP_bin)

DB$CSP_bin2 <- NA
DB[which(DB$CSP_bin==1),]$CSP_bin2 <- 0
DB[which(DB$CSP_bin>1),]$CSP_bin2 <- 1

table(DB$CSP_bin2, exclude = NULL)

# ===============================================================================================================
# ajout des donnes de traitement

library(readxl)
donnees_traitement <- read_excel("D:/Dropbox/UIMM/BorderLine Jerome/8 - Article 2/Modeles Mixtes/donnees traitement.xlsx")

DB <- merge(DB, donnees_traitement,by="z1" , all.x = TRUE)

table(DB$traitement, DB$borderline, exclude = NULL)


# Ajouts des infos :  TCA , EDM , Anxit

donnees_TCA <- read.xlsx(paste(chemin,"BorderLine Jerome/8 - Article 2/donnees TCA EDM anxi/Classeur1.xlsx",sep=""),
                  sheet = 1,colNames = TRUE)

names(donnees_TCA)


DB <- merge(DB, donnees_TCA,by="z1" , all.x = TRUE)

##################################################################################################

DBMM <- DB[which(!is.na(DB$MM_Delai)),]

##################################################################################################
# SCORES SOMMES :

#ON CREE LES DUMMIES POUR LES SCORES
# CTQ : 0 si <= seuil ,  1 si > seuil


DB$CTQ_PN_bin <- cut(DB$CTQ_PN,breaks=c(0,9,26), right=FALSE , labels=FALSE)-1
DB$CTQ_EN_bin <- cut(DB$CTQ_EN,breaks=c(0,14,26), right=FALSE , labels=FALSE)-1
DB$CTQ_EA_bin <- cut(DB$CTQ_EA,breaks=c(0,12,26), right=FALSE , labels=FALSE)-1
DB$CTQ_PA_bin <- cut(DB$CTQ_PA,breaks=c(0,9,26), right=FALSE , labels=FALSE)-1
DB$CTQ_SA_bin <- cut(DB$CTQ_SA,breaks=c(0,7,26), right=FALSE , labels=FALSE)-1

# PBI soin : 1 si Soin bas
DB$PBI_soin_Mere_bin <- 2-cut(DB$PBI_soin_Mere,breaks=c(0,27,Inf), right=FALSE , labels=FALSE)
DB$PBI_soin_Pere_bin <- 2-cut(DB$PBI_soin_Pere,breaks=c(0,24,Inf), right=FALSE , labels=FALSE)

# PBI control : 1 si Control haut
DB$PBI_surpro_Mere_bin <- cut(DB$PBI_surpro_Mere,breaks=c(0,13.5,Inf), right=FALSE, labels=FALSE)-1
DB$PBI_surpro_Pere_bin <- cut(DB$PBI_surpro_Pere,breaks=c(0,12.5,Inf), right=FALSE, labels=FALSE)-1
# ===============================================================================================================
# CALCULS DES SCORES

# Intrusion = PBI_control Pere + PBI control mere + CTQ_EA + CTQ_SA + CTQ_PA
DB$Score_intrusion <- as.numeric(DB$PBI_surpro_Pere_bin) + as.numeric(DB$PBI_surpro_Mere_bin) + as.numeric(DB$CTQ_EA_bin) + as.numeric(DB$CTQ_PA_bin) + as.numeric(DB$CTQ_SA_bin) 
# abandon sans la dimension maladies/sepratations/TS
DB$Score_abandon <-   as.numeric(DB$PBI_soin_Mere_bin) +  as.numeric(DB$PBI_soin_Pere_bin) + as.numeric(DB$CTQ_EN_bin) + as.numeric(DB$CTQ_PN_bin) 
# ===============================================================================================================

#ON CREE LES DUMMIES POUR LES SCORES
# CTQ : 0 si <= seuil ,  1 si > seuil

str(DBMM$PBI_surpro_Mere)

DBMM$CTQ_PN_bin <- cut(DBMM$CTQ_PN,breaks=c(0,9,26), right=FALSE , labels=FALSE)-1
DBMM$CTQ_EN_bin <- cut(DBMM$CTQ_EN,breaks=c(0,14,26), right=FALSE , labels=FALSE)-1
DBMM$CTQ_EA_bin <- cut(DBMM$CTQ_EA,breaks=c(0,12,26), right=FALSE , labels=FALSE)-1
DBMM$CTQ_PA_bin <- cut(DBMM$CTQ_PA,breaks=c(0,9,26), right=FALSE , labels=FALSE)-1
DBMM$CTQ_SA_bin <- cut(DBMM$CTQ_SA,breaks=c(0,7,26), right=FALSE , labels=FALSE)-1

# PBI soin : 1 si Soin bas
DBMM$PBI_soin_Mere_bin <- 2-cut(DBMM$PBI_soin_Mere,breaks=c(0,27,Inf), right=FALSE , labels=FALSE)
DBMM$PBI_soin_Pere_bin <- 2-cut(DBMM$PBI_soin_Pere,breaks=c(0,24,Inf), right=FALSE , labels=FALSE)

# PBI control : 1 si Control haut
DBMM$PBI_surpro_Mere_bin <- cut(DBMM$PBI_surpro_Mere,breaks=c(0,13.5,Inf), right=FALSE, labels=FALSE)-1
DBMM$PBI_surpro_Pere_bin <- cut(DBMM$PBI_surpro_Pere,breaks=c(0,12.5,Inf), right=FALSE, labels=FALSE)-1
# ===============================================================================================================
# CALCULS DES SCORES

# Intrusion = PBI_control Pere + PBI control mere + CTQ_EA + CTQ_SA + CTQ_PA
DBMM$Score_intrusion <- as.numeric(DBMM$PBI_surpro_Pere_bin) + as.numeric(DBMM$PBI_surpro_Mere_bin) + as.numeric(DBMM$CTQ_EA_bin) + as.numeric(DBMM$CTQ_PA_bin) + as.numeric(DBMM$CTQ_SA_bin) 
# abandon sans la dimension maladies/sepratations/TS
DBMM$Score_abandon <-   as.numeric(DBMM$PBI_soin_Mere_bin) +  as.numeric(DBMM$PBI_soin_Pere_bin) + as.numeric(DBMM$CTQ_EN_bin) + as.numeric(DBMM$CTQ_PN_bin) 
# ===============================================================================================================
# ===============================================================================================================






## Quels Borderlines sont au dessus de la mediane des borderlines :
DBMM$BL_succes_haut <- 0
DBMM[which(DBMM$BL=="Borderline" & DBMM$MM_Succes > 0.833333),]$BL_succes_haut <- 1
DBMM[which(DBMM$BL=="Borderline" & DBMM$MM_Succes < 0.833333),]$BL_succes_haut <- 2

aggregate(MM_Succes ~BL_succes_haut ,DBMM,mean)

## Quels borderlines ont un delai plus petit que la mediane des BL :
DBMM$BL_delai_faible <- 0
DBMM[which(DBMM$BL=="Borderline" & DBMM$MM_Delai <  33.15),]$BL_delai_faible <- 1
DBMM[which(DBMM$BL=="Borderline" & DBMM$MM_Delai > 33.15),]$BL_delai_faible <- 2

aggregate(MM_Delai ~ BL_delai_faible ,DBMM,mean)
aggregate(Score_abandon ~ BL_delai_faible ,DBMM,mean)
aggregate(Score_abandon ~ BL_delai_faible ,DBMM,mean)


DBMM$SIDP_BL_cat_N <- as.numeric(DBMM$SIDP_BL_cat)

GRAPH1 <- ggplot(DBMM, aes(x=MM_Delai, y= SIDP_BL_cat_N , color = BL_strict)) +
  geom_jitter(size=2) +
  theme_ipsum() + geom_vline(xintercept=28.56686)

GRAPH2 <- ggplot(DBMM, aes(x=MM_Succes, y= SIDP_BL_cat_N , color = BL_strict)) +
  geom_jitter(size=2) +
  theme_ipsum() + geom_vline(xintercept=0.84)

mean(DB[which(DB$BL_strict=="Tmoin"),]$MM_Succes, na.rm =T)
mean(DB[which(DB$BL_strict=="Tmoin"),]$MM_Delai, na.rm =T)

GRAPH1
GRAPH2